@@ -1,6 +1,6 @@
 jags2 <- function (data, inits, parameters.to.save, model.file = "model.bug", 
   n.chains = 3, n.iter = 2000, n.burnin = floor(n.iter/2), 
-  n.thin = max(1, floor((n.iter - n.burnin)/n.sims)), n.sims=1000, 
+  n.thin = max(1, floor((n.iter - n.burnin)/1000)),
   DIC = TRUE, jags.path = "", working.directory = NULL, clearWD = TRUE,
   refresh = n.iter/50) 
 {
